@@ -1,8 +1,13 @@
-__version__ = "2.8.0"
+__version__ = "2.10.0"
 
 from . import (article, beikeisland, collection, island, notebook, objects,
                rank, user)
 
+__all__ = [
+    "article", "beikeisland", "collection", "island", "notebook", "objects",
+    "rank", "user"
+]
+
 
 def future():
     """彩蛋
