@@ -1,11 +1,32 @@
 from functools import lru_cache
 from typing import Any
+from re import compile as re_compile
 
 from .basic_apis import (GetArticleJsonDataApi, GetCollectionJsonDataApi,
                          GetIslandJsonDataApi, GetNotebookJsonDataApi,
                          GetUserJsonDataApi)
 from .exceptions import InputError, ResourceError
 
+__all__ = [
+    "JIANSHU_URL_REGEX", "JIANSHU_USER_URL_REGEX",
+    "JIANSHU_ARTICLES_URL_REGEX", "JIANSHU_NOTEBOOK_URL_REGEX",
+    "JIANSHU_COLLECTION_URL_REGEX", "JIANSHU_ISLAND_URL_REGEX",
+    "JIANSHU_ISLAND_POST_URL_REGEX", "AssertType", "AssertJianshuUrl",
+    "AssertUserUrl", "AssertUserStatusNormal", "AssertArticleUrl",
+    "AssertArticleStatusNormal", "AssertCollectionUrl",
+    "AssertCollectionStatusNormal", "AssertIslandUrl",
+    "AssertIslandStatusNormal", "AssertIslandPostUrl"
+]
+
+
+JIANSHU_URL_REGEX = re_compile(r"^https://www\.jianshu\.com/\w{1,2}/\w{6,16}/?$")
+JIANSHU_USER_URL_REGEX = re_compile(r"^https://www\.jianshu\.com/u/\w{6,12}/?$")
+JIANSHU_ARTICLES_URL_REGEX = re_compile(r"^https://www\.jianshu\.com/p/\w{12}/?$")
+JIANSHU_NOTEBOOK_URL_REGEX = re_compile(r"^https://www\.jianshu\.com/nb/\d{7,8}/?$")
+JIANSHU_COLLECTION_URL_REGEX = re_compile(r"^https://www\.jianshu\.com/c/\w{6,12}/?$")
+JIANSHU_ISLAND_URL_REGEX = re_compile(r"^https://www\.jianshu\.com/g/\w{16}/?$")
+JIANSHU_ISLAND_POST_URL_REGEX = re_compile(r"^https://www\.jianshu\.com/gp/\w{16}/?$")
+
 
 def AssertType(object: Any, type_obj: Any) -> None:
     """判断对象是否是指定类型
@@ -22,33 +43,29 @@ def AssertType(object: Any, type_obj: Any) -> None:
 
 
 def AssertJianshuUrl(string: str) -> None:
-    """判断字符串是否是有效的简书 Url
+    """判断字符串是否是有效的简书 URL
 
     Args:
         string (str): 需要进行判断的字符串
 
     Raises:
-        InputError: 字符串不是有效的简书 Url 时抛出此错误
+        InputError: 字符串不是有效的简书 URL 时抛出此错误
     """
-    keyword_to_find = ["https://", "www.jianshu.com"]
-    for keyword in keyword_to_find:
-        if keyword not in string:
-            raise InputError(f"{string} 不是有效的简书 Url")
+    if not JIANSHU_URL_REGEX.fullmatch(string):
+        raise InputError(f"{string} 不是有效的简书 URL")
 
 
 def AssertUserUrl(string: str) -> None:
-    """判断字符串是否是有效的简书用户主页 Url
+    """判断字符串是否是有效的简书用户主页 URL
 
     Args:
         string (str): 需要进行判断的字符串
 
     Raises:
-        InputError: 字符串不是有效的简书用户主页 Url 时抛出此错误
+        InputError: 字符串不是有效的简书用户主页 URL 时抛出此错误
     """
-    keyword_to_find = ["https://", "www.jianshu.com", "/u/"]
-    for keyword in keyword_to_find:
-        if keyword not in string:
-            raise InputError(f"{string} 不是有效的简书用户主页 Url")
+    if not JIANSHU_USER_URL_REGEX.fullmatch(string):
+        raise InputError(f"{string} 不是有效的简书用户主页 URL")
 
 
 @lru_cache(maxsize=64)
@@ -56,7 +73,7 @@ def AssertUserStatusNormal(user_url: str) -> None:
     """判断用户账号状态是否正常
 
     Args:
-        user_url (str): 用户主页 Url
+        user_url (str): 用户主页 URL
 
     Raises:
         ResourceError: 用户账号状态异常时抛出此错误
@@ -65,22 +82,20 @@ def AssertUserStatusNormal(user_url: str) -> None:
     try:
         user_json_data["nickname"]
     except KeyError:
-        raise ResourceError("用户账号状态异常")
+        raise ResourceError(f"用户 {user_url} 账号状态异常")
 
 
 def AssertArticleUrl(string: str) -> None:
-    """判断字符串是否是有效的简书文章 Url
+    """判断字符串是否是有效的简书文章 URL
 
     Args:
         string (str): 需要进行判断的字符串
 
     Raises:
-        InputError: 字符串不是有效的简书文章 Url 时抛出此错误
+        InputError: 字符串不是有效的简书文章 URL 时抛出此错误
     """
-    keyword_to_find = ["https://", "www.jianshu.com", "/p/"]
-    for keyword in keyword_to_find:
-        if keyword not in string:
-            raise InputError(f"{string} 不是有效的简书文章 Url")
+    if not JIANSHU_ARTICLES_URL_REGEX.fullmatch(string):
+        raise InputError(f"{string} 不是有效的简书文章 URL")
 
 
 @lru_cache(maxsize=64)
@@ -88,7 +103,7 @@ def AssertArticleStatusNormal(article_url: str) -> None:
     """判断文章状态是否正常
 
     Args:
-        article_url (str): 文章 Url
+        article_url (str): 文章 URL
 
     Raises:
         ResourceError: 文章状态异常时抛出此错误
@@ -98,29 +113,27 @@ def AssertArticleStatusNormal(article_url: str) -> None:
     try:
         json_obj["show_ad"]
     except KeyError:
-        raise ResourceError("文章状态异常")
+        raise ResourceError(f"文章 {article_url} 状态异常")
 
 
 def AssertNotebookUrl(string: str) -> None:
-    """判断字符串是否是有效的简书文集 Url
+    """判断字符串是否是有效的简书文集 URL
 
     Args:
         string (str): 需要进行判断的字符串
 
     Raises:
-        InputError: 字符串不是有效的简书文集 Url 时抛出此错误
+        InputError: 字符串不是有效的简书文集 URL 时抛出此错误
     """
-    keyword_to_find = ["https://", "www.jianshu.com", "/nb/"]
-    for keyword in keyword_to_find:
-        if keyword not in string:
-            raise InputError(f"{string} 不是有效的简书文集 Url")
+    if not JIANSHU_NOTEBOOK_URL_REGEX.fullmatch(string):
+        raise InputError(f"{string} 不是有效的简书文集 URL")
 
 
 def AssertNotebookStatusNormal(notebook_url: str) -> None:
     """判断文集状态是否正常
 
     Args:
-        notebook_url (str): 文集 Url
+        notebook_url (str): 文集 URL
 
     Raises:
         ResourceError: 文集状态异常时抛出此错误
@@ -130,22 +143,20 @@ def AssertNotebookStatusNormal(notebook_url: str) -> None:
     try:
         json_obj["name"]
     except KeyError:
-        raise ResourceError("文集状态异常")
+        raise ResourceError(f"文集 {notebook_url} 状态异常")
 
 
 def AssertCollectionUrl(string: str) -> None:
-    """判断字符串是否是有效的简书专题 Url
+    """判断字符串是否是有效的简书专题 URL
 
     Args:
         string (str): 需要进行判断的字符串
 
     Raises:
-        InputError: 字符串不是有效的简书专题 Url 时抛出此错误
+        InputError: 字符串不是有效的简书专题 URL 时抛出此错误
     """
-    keyword_to_find = ["https://", "www.jianshu.com", "/c/"]
-    for keyword in keyword_to_find:
-        if keyword not in string:
-            raise InputError(f"{string} 不是有效的简书专题 Url")
+    if not JIANSHU_COLLECTION_URL_REGEX.fullmatch(string):
+        raise InputError(f"{string} 不是有效的简书专题 URL")
 
 
 @lru_cache(maxsize=64)
@@ -153,7 +164,7 @@ def AssertCollectionStatusNormal(collection_url: str) -> None:
     """判断专题状态是否正常
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
 
     Raises:
         ResourceError: 专题状态异常时抛出此错误
@@ -162,22 +173,20 @@ def AssertCollectionStatusNormal(collection_url: str) -> None:
     try:
         collection_json_data["title"]
     except KeyError:
-        raise ResourceError("专题状态异常")
+        raise ResourceError(f"专题 {collection_url} 状态异常")
 
 
 def AssertIslandUrl(string: str) -> None:
-    """判断字符串是否是有效的简书小岛 Url
+    """判断字符串是否是有效的简书小岛 URL
 
     Args:
         string (str): 需要进行判断的字符串
 
     Raises:
-        InputError: 字符串不是有效的简书小岛 Url 时抛出此错误
+        InputError: 字符串不是有效的简书小岛 URL 时抛出此错误
     """
-    keyword_to_find = ["https://", "www.jianshu.com", "/g/"]
-    for keyword in keyword_to_find:
-        if keyword not in string:
-            raise InputError(f"{string} 不是有效的简书小岛 Url")
+    if not JIANSHU_ISLAND_URL_REGEX.fullmatch(string):
+        raise InputError(f"{string} 不是有效的简书小岛 URL")
 
 
 @lru_cache(maxsize=64)
@@ -186,19 +195,17 @@ def AssertIslandStatusNormal(island_url: str) -> None:
     try:
         island_json_data["name"]
     except KeyError:
-        raise ResourceError("小岛状态异常")
+        raise ResourceError(f"小岛 {island_url} 状态异常")
 
 
 def AssertIslandPostUrl(string: str) -> None:
-    """判断字符串是否是有效的简书小岛帖子 Url
+    """判断字符串是否是有效的简书小岛帖子 URL
 
     Args:
         string (str): 需要进行判断的字符串
 
     Raises:
-        InputError: 字符串不是有效的简书小岛帖子 Url 时抛出此错误
+        InputError: 字符串不是有效的简书小岛帖子 URL 时抛出此错误
     """
-    keyword_to_find = ["https://", "www.jianshu.com", "/gp/"]
-    for keyword in keyword_to_find:
-        if keyword not in string:
-            raise InputError(f"{string} 不是有效的简书小岛帖子 Url")
+    if not JIANSHU_ISLAND_POST_URL_REGEX.fullmatch(string):
+        raise InputError(f"{string} 不是有效的简书小岛帖子 URL")
