@@ -1,15 +1,18 @@
+__all__ = ["InputError", "APIError", "ResourceError"]
+
+
 class InputError(Exception):
-    """传入参数错误时抛出此异常
+    """函数参数错误时抛出此异常
     """
     pass
 
 
 class APIError(Exception):
-    """API 受限导致无法获取信息时抛出此异常
+    """由于简书 API 受限导致无法获取数据时抛出此异常
     """
     pass
 
 
 class ResourceError(Exception):
-    """访问的资源状态异常时抛出此异常
+    """访问的资源不存在或无法正常访问时抛出此异常
     """
